# Latvian name day data (conversion to JSON)

These are Python scripts for converting the official Latvian name day datasets to JSON.

There are two datasets - the traditional name day list and the extended name day list.

The converted files are located in the `src/lv-namedays/data` folder.

The datasets are available from Latvia's Open Data Portal under the CC0 license:
- https://data.gov.lv/dati/lv/dataset/latviesu-tradicionalais-un-paplasinatais-kalendarvardu-saraksts

